pub fn data_rect(node_rect: Rect, gutter_left: f32) -> RectExpand description
The data rect for a plot laid out at node_rect, inset by gutter_left
(from left_gutter) and the fixed bottom/top/right gutters. Clamped to
non-negative size.
pub fn data_rect(node_rect: Rect, gutter_left: f32) -> RectThe data rect for a plot laid out at node_rect, inset by gutter_left
(from left_gutter) and the fixed bottom/top/right gutters. Clamped to
non-negative size.